@@ -7,8 +7,6 @@ use warnings;
 use 5.014;
 use utf8;
 
-no if $] >= 5.018, warnings => 'experimental::smartmatch';
-
 use Carp qw(confess);
 use DateTime;
 use DateTime::Format::Strptime;
@@ -22,7 +20,7 @@ use Travel::Status::DE::HAFAS::Journey;
 use Travel::Status::DE::HAFAS::StopFinder;
 use Travel::Status::DE::HAFAS::Stop;
 
-our $VERSION = '4.18';
+our $VERSION = '4.19';
 
 # {{{ Endpoint Definition
 
@@ -619,15 +617,12 @@ sub check_mgate {
 sub add_message {
 	my ( $self, $json, $is_him ) = @_;
 
-	my $short = $json->{txtS};
-	my $text  = $json->{txtN};
-	my $code  = $json->{code};
-	my $prio  = $json->{prio};
+	my $text = $json->{txtN};
+	my $code = $json->{code};
 
 	if ($is_him) {
-		$short = $json->{head};
-		$text  = $json->{text};
-		$code  = $json->{hid};
+		$text = $json->{text};
+		$code = $json->{hid};
 	}
 
 	# Some backends use remL for operator information. We don't want that.
@@ -643,11 +638,7 @@ sub add_message {
 	}
 
 	my $message = Travel::Status::DE::HAFAS::Message->new(
-		short     => $short,
-		text      => $text,
-		code      => $code,
-		prio      => $prio,
-		is_him    => $is_him,
+		json      => $json,
 		ref_count => 1,
 	);
 	push( @{ $self->{messages} }, $message );
@@ -911,7 +902,7 @@ monitors
 
 =head1 VERSION
 
-version 4.18
+version 4.19
 
 =head1 DESCRIPTION
 
@@ -1178,7 +1169,7 @@ Travel::Status::DE::HAFAS::Journey(3pm), Travel::Status::DE::HAFAS::StopFinder(3
 
 =head1 AUTHOR
 
-Copyright (C) 2015-2022 by Birte Kristina Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2015-2023 by Birte Kristina Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
